@@ -47,6 +47,7 @@ from .type_defs import (
     ListManagedEndpointsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     ListVirtualClustersResponseTypeDef,
+    RetryPolicyConfigurationTypeDef,
     StartJobRunResponseTypeDef,
 )
 
@@ -329,7 +330,8 @@ class EMRContainersClient(BaseClient):
         configurationOverrides: ConfigurationOverridesTypeDef = ...,
         tags: Mapping[str, str] = ...,
         jobTemplateId: str = ...,
-        jobTemplateParameters: Mapping[str, str] = ...
+        jobTemplateParameters: Mapping[str, str] = ...,
+        retryPolicyConfiguration: RetryPolicyConfigurationTypeDef = ...
     ) -> StartJobRunResponseTypeDef:
         """
         Starts a job run.
