@@ -11,6 +11,7 @@ Usage::
     from mypy_boto3_emr_containers.client import EMRContainersClient
     from mypy_boto3_emr_containers.paginator import (
         ListJobRunsPaginator,
+        ListJobTemplatesPaginator,
         ListManagedEndpointsPaginator,
         ListVirtualClustersPaginator,
     )
@@ -19,6 +20,7 @@ Usage::
     client: EMRContainersClient = session.client("emr-containers")
 
     list_job_runs_paginator: ListJobRunsPaginator = client.get_paginator("list_job_runs")
+    list_job_templates_paginator: ListJobTemplatesPaginator = client.get_paginator("list_job_templates")
     list_managed_endpoints_paginator: ListManagedEndpointsPaginator = client.get_paginator("list_managed_endpoints")
     list_virtual_clusters_paginator: ListVirtualClustersPaginator = client.get_paginator("list_virtual_clusters")
     ```
@@ -32,6 +34,7 @@ from botocore.paginate import PageIterator, Paginator
 from .literals import EndpointStateType, JobRunStateType, VirtualClusterStateType
 from .type_defs import (
     ListJobRunsResponseTypeDef,
+    ListJobTemplatesResponseTypeDef,
     ListManagedEndpointsResponseTypeDef,
     ListVirtualClustersResponseTypeDef,
     PaginatorConfigTypeDef,
@@ -43,7 +46,12 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ListJobRunsPaginator", "ListManagedEndpointsPaginator", "ListVirtualClustersPaginator")
+__all__ = (
+    "ListJobRunsPaginator",
+    "ListJobTemplatesPaginator",
+    "ListManagedEndpointsPaginator",
+    "ListVirtualClustersPaginator",
+)
 
 
 _ItemTypeDef = TypeVar("_ItemTypeDef")
@@ -78,6 +86,25 @@ class ListJobRunsPaginator(Paginator):
         """
 
 
+class ListJobTemplatesPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobTemplates)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators/#listjobtemplatespaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        createdAfter: Union[datetime, str] = ...,
+        createdBefore: Union[datetime, str] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListJobTemplatesResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobTemplates.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators/#listjobtemplatespaginator)
+        """
+
+
 class ListManagedEndpointsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
