@@ -50,6 +50,8 @@ __all__ = (
     "DescribeVirtualClusterRequestRequestTypeDef",
     "SparkSqlJobDriverTypeDef",
     "SparkSubmitJobDriverTypeDef",
+    "RetryPolicyConfigurationTypeDef",
+    "RetryPolicyExecutionTypeDef",
     "TemplateParameterConfigurationTypeDef",
     "PaginatorConfigTypeDef",
     "ListJobRunsRequestRequestTypeDef",
@@ -262,6 +264,20 @@ class SparkSubmitJobDriverTypeDef(
     pass
 
 
+RetryPolicyConfigurationTypeDef = TypedDict(
+    "RetryPolicyConfigurationTypeDef",
+    {
+        "maxAttempts": int,
+    },
+)
+
+RetryPolicyExecutionTypeDef = TypedDict(
+    "RetryPolicyExecutionTypeDef",
+    {
+        "currentAttemptCount": int,
+    },
+)
+
 TemplateParameterConfigurationTypeDef = TypedDict(
     "TemplateParameterConfigurationTypeDef",
     {
@@ -754,6 +770,8 @@ JobRunTypeDef = TypedDict(
         "stateDetails": str,
         "failureReason": FailureReasonType,
         "tags": Dict[str, str],
+        "retryPolicyConfiguration": RetryPolicyConfigurationTypeDef,
+        "retryPolicyExecution": RetryPolicyExecutionTypeDef,
     },
     total=False,
 )
@@ -776,6 +794,7 @@ _OptionalStartJobRunRequestRequestTypeDef = TypedDict(
         "tags": Mapping[str, str],
         "jobTemplateId": str,
         "jobTemplateParameters": Mapping[str, str],
+        "retryPolicyConfiguration": RetryPolicyConfigurationTypeDef,
     },
     total=False,
 )
